<?php
namespace Factory;

use Doctrine\ORM\EntityManager;

class CpAssinaturaDigitalFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getTokenCertsign (array $params) {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM PARAM_CENTR_ASSINATURA
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /**
     * A função "getDadosSender" recebe os dados de responsável pelo envio do documento
     */
    public function getDadosSender(array $params) {
      $sql = "SELECT NMSENDERCERTSIGN, DSEMAILSENDERCERTSIGN, NRCPFSENDERCERTSIGN, IDPADRAOASSINACERTSIGN, NRTIPODOCCERTSIGN
                FROM PARAM_CENTR_ASSINATURA
               WHERE NRORG = :NRORG";
      
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
    }

    /**
     * A função "insertCentralizaAssinatura" insere os ID do documento gerado no certisign para a integração com o OM.  
     */
    public function insertCentralizaAssinatura(array $params) {
        
      $sql = "INSERT INTO CENTRALIZA_ASSINATURA (ID, DSCHAVEASSINAT, IDDOCASSINAT, NRORG, IDATIVO, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                          VALUES (:ID, :DSCHAVEASSINAT, :IDDOCASSINAT, :NRORG, :IDATIVO, SYSDATE, :CDOPERINCLUSAO, :NRORG)";
                           
      $std = $this->connection->prepare($sql);
      $std->execute($params);
  }

  public function insertSignature(array $params)
  {
      $sql = "INSERT INTO CP_CALL_SIGNATURE (
                  NRCALLSIGNATURE,
                  NRCALL,
                  IDDOCUMCERTSIGN,
                  CHAVEDOCCERTISIGN,
                  IDSIGNATCERTISIGN,
                  NAMESIGNATORY,
                  CPFSIGNATORY,
                  MAILSIGNATORY,
                  DSURLSIGNATURE,
                  IDSITUACAO,
                  DSJUSTIFICARECUSA,
                  CALL_RELATIONSHIP,
                  CALL_REFERENCE,
                  CALL_PRODUCT,
                  CALL_CLASSIFICATION,
                  CALL_BOARD,
                  CALL_DESCRIPTION,
                  CALL_COMMENT,
                  NRORG,
                  IDATIVO,
                  DTINCLUSAO,
                  CDOPERINCLUSAO,
                  NRORGINCLUSAO
              )
              VALUES (
                  :NRCALLSIGNATURE,
                  :NRCALL,
                  :IDDOCUMCERTSIGN,
                  :CHAVEDOCCERTISIGN,
                  :IDSIGNATCERTISIGN,
                  :NAMESIGNATORY,
                  :CPFSIGNATORY,
                  :MAILSIGNATORY,
                  :DSURLSIGNATURE,
                  :IDSITUACAO,
                  NULL,
                  :CALL_RELATIONSHIP,
                  :CALL_REFERENCE,
                  :CALL_PRODUCT,
                  :CALL_CLASSIFICATION,
                  :CALL_BOARD,
                  :CALL_DESCRIPTION,
                  :CALL_COMMENT,
                  :NRORG,
                  'S',
                  SYSDATE,
                  :CDOPERINCLUSAO,
                  :NRORGINCLUSAO
              )";

      $std = $this->connection->prepare($sql);
      $std->execute($params);
  }

  public function getCallSignature(array $params) {
    $sql = "SELECT NRCALLSIGNATURE, NRCALL, CALL_RELATIONSHIP,
                   CALL_REFERENCE, CALL_PRODUCT, CALL_CLASSIFICATION,
                   CALL_BOARD, CALL_DESCRIPTION, CALL_COMMENT
              FROM CP_CALL_SIGNATURE
             WHERE IDDOCUMCERTSIGN = :IDDOCUMCERTSIGN
               AND CPFSIGNATORY = :CPFSIGNATORY";
    
    $std = $this->connection->prepare($sql);
    $std->execute($params);
    return $std->fetchAll();
  }

  /*Atualiza situação dos documentos das assinaturas da proposta*/
  public function updateCallSignature(array $params) {
    $sql = "UPDATE CP_CALL_SIGNATURE
               SET IDSITUACAO        = :IDSITUACAO,
                   DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                   DTULTATU          = SYSDATE
             WHERE NRCALLSIGNATURE     = :NRCALLSIGNATURE
               AND CPFSIGNATORY = :CPFSIGNATORY";

    $std = $this->connection->prepare($sql);
    $std->execute($params);
  }

  public function insertLogCallSignature(array $params) {
    $sql = "INSERT INTO CP_LOGCALLSIGNATURE (
                NRLOGCALLSIGNATURE, NRCALL,  IDDOCUMCERTSIGN,       
                CPFSIGNATORY,       DSERRO,  NRORG, 
                DTINCLUSAO
            )
            VALUES (
                :NRLOGCALLSIGNATURE, :NRCALL, :IDDOCUMCERTSIGN,      
                :CPFSIGNATORY,       :DSERRO, :NRORG,
                SYSDATE
            )";
    
    $ps = $this->connection->prepare($sql);
    $ps->execute($params);
  }

  /**
     * A função "getIdDocCertsign" recebe os ids dos documentos do Certsign
     */
  public function getIdDocCertsign(array $params) {        
      $sql = "SELECT IDDOCUMCERTSIGN, CHAVEDOCCERTISIGN, IDSIGNATCERTISIGN, CPFSIGNATORY, DSURLSIGNATURE
                FROM CP_CALL_SIGNATURE
               WHERE NRCALL = :NRCALL";
      
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
  }

}
?>